@@ -1,14 +1,16 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
  * SPDX-License-Identifier: BSD-3-Clause
  */
 #pragma once
-#include "hip_wrappers.hpp"
+
+#include "cuda_runtime.hpp"
+#include "host_device.hpp"
 
 namespace gridtools {
     /** \ingroup common
@@ -235,10 +237,6 @@ namespace gridtools {
         }
     };
 
-    template <typename T>
-    struct get_atomic_helper {
-        typedef atomic_cuda<T> type;
-    };
     /** @} */
     /** @} */
 } // namespace gridtools
