@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -18,8 +18,10 @@
     @{
 */
 
-#ifdef GT_USE_GPU
-#include "hip_wrappers.hpp"
+#include "defs.hpp"
+
+#ifdef __HIPCC__
+#include "cuda_runtime.hpp"
 #endif
 
 #if defined(__NVCC__)
@@ -54,18 +56,17 @@
  * function. This macro is only needed to supress NVCC warnings.
  */
 
-#ifdef __CUDACC__
+#ifdef GT_CUDACC
 #define GT_HOST_DEVICE __host__ __device__
 #ifdef __NVCC__ // NVIDIA CUDA compilation
 #define GT_DEVICE __device__
 #define GT_HOST __host__
-#else // Clang CUDA compilation
+#else // Clang CUDA or HIP compilation
 #define GT_DEVICE __device__ __host__
 #define GT_HOST __host__
 #endif
 #else
 #define GT_HOST_DEVICE
-#define GT_DEVICE
 #define GT_HOST
 #endif
 
@@ -88,7 +89,7 @@
 /**
  *   A helper to implement a family of functions which are different from each other only by target specifies.
  *
- *   It uses the same design pattern as `BOOST_PP_ITERATE` does.
+ *   It uses the same design pattern as `GT_PP_ITERATE` does.
  *   For example if one wants to define a function with any possible combination of `__host__` and `__device__`
  *   specifiers he needs to write the following code:
  *
