@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -15,23 +15,62 @@
 #include "host_device.hpp"
 
 namespace gridtools {
+    // This predicate checks if the the class has `std::integral_constant` as a public base.
+    // Note that it is not the same as `class is an instantiation of gridtools::integral_constant`.
+    // Also it is not the same as `class has `integral nested value_type type and value static member`.
+    template <class, class = void>
+    struct is_integral_constant : std::false_type {};
+
+    template <class T>
+    struct is_integral_constant<T,
+        std::enable_if_t<std::is_base_of<std::integral_constant<typename T::value_type, T::value>, T>::value>>
+        : std::true_type {};
+
+    template <class T, int Val, class = void>
+    struct is_integral_constant_of : std::false_type {};
+
+    template <class T, int Val>
+    struct is_integral_constant_of<T, Val, std::enable_if_t<is_integral_constant<T>::value && T() == Val>>
+        : std::true_type {};
+
     template <class T, T V>
     struct integral_constant : std::integral_constant<T, V> {
         using type = integral_constant;
 
-#if defined(__INTEL_COMPILER) && __INTEL_COMPILER < 1900
-        constexpr GT_FORCE_INLINE integral_constant() noexcept {}
-#endif
-
         constexpr GT_FUNCTION operator T() const noexcept { return V; }
     };
 
+    // Returns the value_type of an integral_constant or returns the type itself
+    template <class, class = void>
+    struct to_integral_type;
+    template <class T>
+    struct to_integral_type<T, std::enable_if_t<std::is_integral_v<T>>> {
+        using type = T;
+    };
+    template <class T>
+    struct to_integral_type<T, std::enable_if_t<is_integral_constant<T>::value>> {
+        using type = typename T::value_type;
+    };
+
+    template <class T>
+    using to_integral_type_t = typename to_integral_type<T>::type;
+
+    // This predicate checks if the the class has `gridtools::integral_constant` as a public base, which has arithmetic
+    // operators defined.
+    template <class, class = void>
+    struct is_gr_integral_constant : std::false_type {};
+
+    template <class T>
+    struct is_gr_integral_constant<T,
+        std::enable_if_t<std::is_base_of<integral_constant<typename T::value_type, T::value>, T>::value>>
+        : std::true_type {};
+
 #define GT_INTEGRAL_CONSTANT_DEFINE_UNARY_OPERATOR(op, type)                                                           \
     template <class T, T V>                                                                                            \
     constexpr GT_FUNCTION integral_constant<decltype(op V), (op V)> operator op(integral_constant<T, V> &&) noexcept { \
         return {};                                                                                                     \
     }                                                                                                                  \
-    static_assert(1, "")
+    static_assert(1)
 
     GT_INTEGRAL_CONSTANT_DEFINE_UNARY_OPERATOR(+, T);
     GT_INTEGRAL_CONSTANT_DEFINE_UNARY_OPERATOR(-, T);
@@ -46,7 +85,7 @@ namespace gridtools {
         integral_constant<T, TV>, integral_constant<U, UV>) noexcept {                   \
         return {};                                                                       \
     }                                                                                    \
-    static_assert(1, "")
+    static_assert(1)
 
     GT_INTEGRAL_CONSTANT_DEFINE_BINARY_OPERATOR(+, (std::common_type_t<T, U>));
     GT_INTEGRAL_CONSTANT_DEFINE_BINARY_OPERATOR(-, (std::common_type_t<T, U>));
@@ -79,24 +118,22 @@ namespace gridtools {
             template <>
             constexpr literal_int_t to_int<2>(char c) {
                 return c == '0' ? 0 : c == '1' ? 1 : throw "invalid binary _c literal";
-            };
-
+            }
             template <>
             constexpr literal_int_t to_int<8>(char c) {
                 return c >= '0' && c <= '7' ? c - '0' : throw "invalid octal _c literal";
-            };
+            }
             template <>
             constexpr literal_int_t to_int<10>(char c) {
                 return c >= '0' && c <= '9' ? c - '0' : throw "invalid decimal _c literal";
-            };
-
+            }
             template <>
             constexpr literal_int_t to_int<16>(char c) {
-                return c >= 'A' && c <= 'F'
-                           ? c - 'A' + 10
-                           : c >= 'a' && c <= 'f' ? c - 'a' + 10
-                                                  : c >= '0' && c <= '9' ? c - '0' : throw "invalid hex _c literal";
-            };
+                return c >= 'A' && c <= 'F'   ? c - 'A' + 10
+                       : c >= 'a' && c <= 'f' ? c - 'a' + 10
+                       : c >= '0' && c <= '9' ? c - '0'
+                                              : throw "invalid hex _c literal";
+            }
 
             template <literal_int_t Base>
             constexpr literal_int_t parse(char const *first, char const *last) {
