@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -28,11 +28,12 @@
 
 #define GT_TARGET_ITERATING
 
-#ifdef __CUDACC__
+#ifdef GT_CUDACC
 
 #define GT_TARGET_NAMESPACE_NAME host
 #define GT_TARGET_NAMESPACE inline namespace host
 #define GT_TARGET GT_HOST
+
 #include GT_FILENAME
 #undef GT_TARGET
 #undef GT_TARGET_NAMESPACE
@@ -63,9 +64,6 @@
 #define GT_TARGET_NAMESPACE_NAME host
 #define GT_TARGET_NAMESPACE   \
     inline namespace host {}  \
-    namespace device {        \
-        using namespace host; \
-    }                         \
     namespace host_device {   \
         using namespace host; \
     }                         \
@@ -75,7 +73,6 @@
 #undef GT_TARGET
 #undef GT_TARGET_NAMESPACE
 #undef GT_TARGET_NAMESPACE_NAME
-
 #endif
 
 #undef GT_TARGET_ITERATING
