@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -10,25 +10,22 @@
 
 #pragma once
 
-#include "defs.hpp"
 #include "id.hpp"
 #include "macros.hpp"
 
 namespace gridtools {
     namespace meta {
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <class T>
             struct always {
                 template <class...>
                 struct apply : id<T> {};
             };
-        }
-#if !GT_BROKEN_TEMPLATE_ALIASES
+        } // namespace lazy
         template <class T>
         struct always {
             template <class...>
             using apply = T;
         };
-#endif
     } // namespace meta
 } // namespace gridtools
