@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -24,16 +24,14 @@ namespace gridtools {
         template <class L>
         struct cartesian_product_step_impl_impl {
             template <class T>
-            GT_META_DEFINE_ALIAS(
-                apply, transform, (curry<push_back, T>::template apply, GT_META_CALL(rename, (list, L))));
+            using apply = transform<curry<push_back, T>::template apply, rename<list, L>>;
         };
 
         template <class S, class L>
-        GT_META_DEFINE_ALIAS(cartesian_product_step_impl,
-            rename,
-            (concat, GT_META_CALL(transform, (cartesian_product_step_impl_impl<L>::template apply, S))));
+        using cartesian_product_step_impl =
+            rename<concat, transform<cartesian_product_step_impl_impl<L>::template apply, S>>;
 
         template <class... Lists>
-        GT_META_DEFINE_ALIAS(cartesian_product, lfold, (cartesian_product_step_impl, list<list<>>, list<Lists...>));
+        using cartesian_product = foldl<cartesian_product_step_impl, list<list<>>, list<Lists...>>;
     } // namespace meta
 } // namespace gridtools
