@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -10,21 +10,22 @@
 
 #pragma once
 
-#include "combine.hpp"
 #include "list.hpp"
 #include "macros.hpp"
 
+#include "fold.hpp"
+
 namespace gridtools {
     namespace meta {
         /**
          *  Concatenate lists
          */
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <class...>
             struct concat;
         }
         GT_META_DELEGATE_TO_LAZY(concat, class... Lists, Lists...);
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <>
             struct concat<> : list<> {};
             template <template <class...> class L, class... Ts>
@@ -36,8 +37,8 @@ namespace gridtools {
                 using type = L1<T1s..., T2s...>;
             };
 
-            template <class L1, class L2, class L3, class... Lists>
-            struct concat<L1, L2, L3, Lists...> : combine<meta::concat, list<L1, L2, L3, Lists...>> {};
-        }
-    } // namespace meta
+            template <class List, class... Lists>
+            struct concat<List, Lists...> : foldl<meta::concat, List, list<Lists...>> {};
+        } // namespace lazy
+    }     // namespace meta
 } // namespace gridtools
