@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -19,13 +19,13 @@ namespace gridtools {
      *  Filter the list based of predicate
      */
     namespace meta {
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <template <class...> class, class...>
             struct filter;
         }
         GT_META_DELEGATE_TO_LAZY(filter, (template <class...> class F, class... Args), (F, Args...));
 
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <bool, template <class...> class L, class T>
             struct wrap_if_impl {
                 using type = L<T>;
@@ -41,7 +41,8 @@ namespace gridtools {
                 using type = curry_fun<meta::filter, Pred>;
             };
             template <template <class...> class Pred, template <class...> class L, class... Ts>
-            struct filter<Pred, L<Ts...>> : concat<L<>, typename wrap_if_impl<Pred<Ts>::value, L, Ts>::type...> {};
-        }
-    } // namespace meta
+            struct filter<Pred, L<Ts...>> : concat<L<>, typename wrap_if_impl<Pred<Ts>::type::value, L, Ts>::type...> {
+            };
+        } // namespace lazy
+    }     // namespace meta
 } // namespace gridtools
