@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -10,10 +10,8 @@
 
 #pragma once
 
-#include "combine.hpp"
 #include "concat.hpp"
-#include "defs.hpp"
-#include "macros.hpp"
+#include "rename.hpp"
 
 namespace gridtools {
     /**
@@ -22,13 +20,11 @@ namespace gridtools {
      *  Note: this function doesn't go recursive. It just concatenates the inner lists.
      */
     namespace meta {
-        GT_META_LAZY_NAMESPACE {
-            template <class Lists>
-            GT_META_DEFINE_ALIAS(flatten, combine, (meta::concat, Lists));
-        }
-#if !GT_BROKEN_TEMPLATE_ALIASES
-        template <class Lists>
-        using flatten = typename lazy::combine<concat, Lists>::type;
-#endif
+        namespace lazy {
+            template <class T>
+            using flatten = rename<meta::concat, T>;
+        } // namespace lazy
+        template <class T>
+        using flatten = rename<concat, T>;
     } // namespace meta
 } // namespace gridtools
