@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -10,7 +10,6 @@
 
 #pragma once
 
-#include "defs.hpp"
 #include "macros.hpp"
 
 namespace gridtools {
@@ -18,15 +17,13 @@ namespace gridtools {
         /**
          *  Identity
          */
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <class T>
             struct id {
                 using type = T;
             };
-        }
-#if !GT_BROKEN_TEMPLATE_ALIASES
+        } // namespace lazy
         template <class T>
         using id = T;
-#endif
     } // namespace meta
 } // namespace gridtools
