@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -21,15 +21,9 @@
 namespace gridtools {
     namespace meta {
         template <size_t N, class List, class... Ts>
-        GT_META_DEFINE_ALIAS(insert_c,
-            concat,
-            (GT_META_CALL(take_c, (N, List)),
-                GT_META_CALL(push_front, (GT_META_CALL(drop_front_c, (N, List)), Ts...))));
+        using insert_c = concat<take_c<N, List>, push_front<drop_front_c<N, List>, Ts...>>;
 
         template <class N, class List, class... Ts>
-        GT_META_DEFINE_ALIAS(insert,
-            concat,
-            (GT_META_CALL(take_c, (N::value, List)),
-                GT_META_CALL(push_front, (GT_META_CALL(drop_front_c, (N::value, List)), Ts...))));
+        using insert = concat<take_c<N::value, List>, push_front<drop_front_c<N::value, List>, Ts...>>;
     } // namespace meta
 } // namespace gridtools
