@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -16,7 +16,6 @@
 #include "id.hpp"
 #include "internal/inherit.hpp"
 #include "macros.hpp"
-#include "type_traits.hpp"
 
 namespace gridtools {
     namespace meta {
@@ -27,7 +26,7 @@ namespace gridtools {
         struct is_set : std::false_type {};
 
         template <template <class...> class L, class... Ts>
-        struct is_set<L<Ts...>> : std::is_same<L<Ts...>, GT_META_CALL(dedup, L<Ts...>)> {};
+        struct is_set<L<Ts...>> : std::is_same<L<Ts...>, dedup<L<Ts...>>> {};
 
         /**
          *   is_set_fast evaluates to std::true_type if the parameter is a set.
@@ -40,6 +39,6 @@ namespace gridtools {
         struct is_set_fast : std::false_type {};
 
         template <template <class...> class L, class... Ts>
-        struct is_set_fast<L<Ts...>, void_t<decltype(internal::inherit<lazy::id<Ts>...>{})>> : std::true_type {};
+        struct is_set_fast<L<Ts...>, std::void_t<decltype(internal::inherit<lazy::id<Ts>...>{})>> : std::true_type {};
     } // namespace meta
 } // namespace gridtools
