@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -12,17 +12,17 @@
 
 #include <type_traits>
 
-#include <boost/preprocessor/punctuation/remove_parens.hpp>
+#include <gridtools/preprocessor/punctuation/remove_parens.hpp>
 
 #define GT_META_DELEGATE_TO_LAZY(fun, signature, args) \
-    template <BOOST_PP_REMOVE_PARENS(signature)>       \
-    using fun = typename lazy::fun<BOOST_PP_REMOVE_PARENS(args)>::type
+    template <GT_PP_REMOVE_PARENS(signature)>       \
+    using fun = typename lazy::fun<GT_PP_REMOVE_PARENS(args)>::type
 
 /**
  *  NVCC bug workaround: sizeof... works incorrectly within template alias context.
  */
 #if defined(__CUDACC_VER_MAJOR__) && \
-    (__CUDACC_VER_MAJOR__ < 10 || (__CUDACC_VER_MAJOR__ == 10 && __CUDACC_VER_MINOR__ < 2))
+    (__CUDACC_VER_MAJOR__ < 11 || (__CUDACC_VER_MAJOR__ == 11 && __CUDACC_VER_MINOR__ <= 8))
 
 namespace gridtools {
     namespace meta {
