@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -14,7 +14,7 @@
 
 namespace gridtools {
     namespace meta {
-        GT_META_LAZY_NAMESPACE {
+        namespace lazy {
             template <class>
             struct pop_front;
 
@@ -22,7 +22,11 @@ namespace gridtools {
             struct pop_front<L<T, Ts...>> {
                 using type = L<Ts...>;
             };
-        }
+            template <template <class...> class L>
+            struct pop_front<L<>> {
+                using type = L<>;
+            };
+        } // namespace lazy
         GT_META_DELEGATE_TO_LAZY(pop_front, class List, List);
     } // namespace meta
 } // namespace gridtools
