@@ -1,7 +1,7 @@
 /*
  * GridTools
  *
- * Copyright (c) 2014-2019, ETH Zurich
+ * Copyright (c) 2014-2023, ETH Zurich
  * All rights reserved.
  *
  * Please, refer to the LICENSE file in the root directory.
@@ -43,9 +43,11 @@ namespace gridtools {
                 using type = L<F<Ts>...>;
             };
             template <template <class...> class F,
-                template <class...> class L1,
+                template <class...>
+                class L1,
                 class... T1s,
-                template <class...> class L2,
+                template <class...>
+                class L2,
                 class... T2s>
             struct transform<F, L1<T1s...>, L2<T2s...>> {
                 using type = L1<F<T1s, T2s>...>;
@@ -64,7 +66,7 @@ namespace gridtools {
             };
             template <template <class...> class Outer, template <class...> class Inner, class... Ts, class... Inners>
             struct transpose<Outer<Inner<Ts...>, Inners...>>
-                : lfold<transform<meta::push_back>::type::apply, Inner<Outer<Ts>...>, list<Inners...>> {};
+                : foldl<transform<meta::push_back>::type::apply, Inner<Outer<Ts>...>, list<Inners...>> {};
 
             // transform, generic version
             template <template <class...> class F, class List, class... Lists>
